summaryrefslogtreecommitdiff
path: root/starmath/source/document.cxx
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2021-04-19 15:22:22 +0100
committerCaolán McNamara <caolanm@redhat.com>2021-04-21 18:02:15 +0200
commitea21b870f8549d0110ef65187af50694a06458ca (patch)
tree0d0c2d203e80a5f94bfeaad0e1c373ff2e1b20cd /starmath/source/document.cxx
parent967da14b48035f5acdd8a604a5c33cc6fe37035a (diff)
weld SmGraphicWindow
Change-Id: Ie163640d6453f30d1cebdaf75ecd41374b2b9ec3 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/114351 Tested-by: Jenkins Reviewed-by: Caolán McNamara <caolanm@redhat.com>
Diffstat (limited to 'starmath/source/document.cxx')
-rw-r--r--starmath/source/document.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/starmath/source/document.cxx b/starmath/source/document.cxx
index c3faff24b8d1..10fee0c6f39c 100644
--- a/starmath/source/document.cxx
+++ b/starmath/source/document.cxx
@@ -174,7 +174,7 @@ void SmDocShell::SetText(const OUString& rBuffer)
Repaint();
}
else
- pViewSh->GetGraphicWindow().Invalidate();
+ pViewSh->GetGraphicWidget().Invalidate();
}
if ( bIsEnabled )
@@ -182,7 +182,7 @@ void SmDocShell::SetText(const OUString& rBuffer)
SetModified();
// launch accessible event if necessary
- SmGraphicAccessible *pAcc = pViewSh ? pViewSh->GetGraphicWindow().GetAccessible_Impl() : nullptr;
+ SmGraphicAccessible *pAcc = pViewSh ? pViewSh->GetGraphicWidget().GetAccessible_Impl() : nullptr;
if (pAcc)
{
Any aOldValue, aNewValue;
@@ -260,7 +260,7 @@ void SmDocShell::ArrangeFormula()
{
SmViewShell *pView = SmGetActiveView();
if (pView)
- pOutDev = &pView->GetGraphicWindow();
+ pOutDev = &pView->GetGraphicWidget().GetDrawingArea()->get_ref_device();
else
{
pOutDev = &SM_MOD()->GetDefaultVirtualDev();
@@ -622,7 +622,7 @@ void SmDocShell::Repaint()
SetVisAreaSize(aVisSize);
SmViewShell* pViewSh = SmGetActiveView();
if (pViewSh)
- pViewSh->GetGraphicWindow().Invalidate();
+ pViewSh->GetGraphicWidget().Invalidate();
if (bIsEnabled)
EnableSetModified(bIsEnabled);
@@ -1145,7 +1145,7 @@ void SmDocShell::GetState(SfxItemSet &rSet)
break;
case SID_GRAPHIC_SM:
//! very old (pre UNO) and ugly hack to invalidate the SmGraphicWindow.
//! If mnModifyCount gets changed then the call below will implicitly notify
//! SmGraphicController::StateChanged and there the window gets invalidated.
//! Thus all the 'mnModifyCount++' before invalidating this slot.
@@ -1145,7 +1145,7 @@ void SmDocShell::GetState(SfxItemSet &rSet)
break;
case SID_GRAPHIC_SM:
- //! very old (pre UNO) and ugly hack to invalidate the SmGraphicWindow.
+ //! very old (pre UNO) and ugly hack to invalidate the SmGraphicWidget.
//! If mnModifyCount gets changed then the call below will implicitly notify
//! SmGraphicController::StateChanged and there the window gets invalidated.